@@ -127,7 +127,7 @@ def namespaced_query_string(d, prefix=""):
     return qs
 
 
-def make_request(method, url, params, verify_ssl=False):
+def make_request(method, url, params):
     """Make an HTTP request, formatting params as required."""
     empty = []
     for key, value in params.iteritems():
@@ -136,25 +136,32 @@ def make_request(method, url, params, verify_ssl=False):
     for key in empty:
         del params[key]
 
-    files = namespaced_query_string(extract_files_from_dict(params))
-    data = namespaced_query_string(remove_files_from_dict(params))
-
-    request_func = getattr(requests, method, None)
-    if request_func is None:
-        raise TypeError('Unknown method: %s' % (method,))
-
     # allow caller to disable automatic following of redirects
     allow_redirects = params.get('allow_redirects', True)
+
     kwargs = {
         'allow_redirects': allow_redirects,
         'headers': {
             'User-Agent': soundcloud.USER_AGENT
         }
     }
-    if 'allow_redirects' in data:
-        del data['allow_redirects']
-    if not verify_ssl:
-        kwargs['verify_ssl'] = False
+    # options, not params
+    if 'verify_ssl' in params:
+        if params['verify_ssl'] is False:
+            kwargs['verify'] = params['verify_ssl']
+        del params['verify_ssl']
+    if 'proxies' in params:
+        kwargs['proxies'] = params['proxies']
+        del params['proxies']
+    if 'allow_redirects' in params:
+        del params['allow_redirects']
+
+    files = namespaced_query_string(extract_files_from_dict(params))
+    data = namespaced_query_string(remove_files_from_dict(params))
+
+    request_func = getattr(requests, method, None)
+    if request_func is None:
+        raise TypeError('Unknown method: %s' % (method,))
 
     if method == 'get':
         qs = urllib.urlencode(data)
